"use strict";
import axios from "axios";
import { Toast } from "vant";
import router from "@/router";

let config = {
  baseURL: import.meta.env.VITE_APP_CYGX_BASEAPIURL,
  timeout: 60 * 1000, // Timeout
};

const _axios = axios.create(config);

_axios.interceptors.request.use(
  function (config) {
    let auth = localStorage.getItem("cygx_token") || "";
    if (auth) {
      config.headers.Authorization = auth;
    }

    return config;
  },
  function (error) {
    return Promise.reject(error);
  }
);

_axios.interceptors.response.use(
  function (response) {
    if (response.data.Ret == 408) {
      localStorage.removeItem("cygx_token");
      router.push("/cygx/login");
    }
    return response.data;
  },
  function (error) {
    return Promise.reject(error);
  }
);

/**
 * 导出get请求方法
 * @url 请求地址
 * @params get请求参数
 */
export const get = (url, params) => {
  return _axios.get(url, { params });
};

/**
 * 导出post请求方法
 * @url 请求地址
 * @params post请求参数
 */
export const post = (url, params) => {
  return _axios.post(url, params);
};
